@@ -28,7 +28,8 @@
 
 #include <glib.h>
 
-gchar*      xkb_util_get_flag_filename      (const gchar* group_name);
+gchar*      xkb_util_get_flag_filename      (const gchar* group_name,
+                                             const gchar *variant);
 
 gchar*      xkb_util_get_layout_string      (const gchar* group_name,
                                              const gchar* variant);
